# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VpcCenTrFirewallArgs', 'VpcCenTrFirewall']

@pulumi.input_type
class VpcCenTrFirewallArgs:
    def __init__(__self__, *,
                 cen_id: pulumi.Input[str],
                 firewall_name: pulumi.Input[str],
                 firewall_subnet_cidr: pulumi.Input[str],
                 firewall_vpc_cidr: pulumi.Input[str],
                 region_no: pulumi.Input[str],
                 route_mode: pulumi.Input[str],
                 tr_attachment_master_cidr: pulumi.Input[str],
                 tr_attachment_slave_cidr: pulumi.Input[str],
                 transit_router_id: pulumi.Input[str],
                 firewall_description: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_zone: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_zone: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VpcCenTrFirewall resource.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] firewall_name: The name of Cloud Firewall.
        :param pulumi.Input[str] firewall_subnet_cidr: Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        :param pulumi.Input[str] firewall_vpc_cidr: Required in automatic mode,  th CIDR of firewall VPC.
        :param pulumi.Input[str] region_no: The region ID of the transit router instance.
        :param pulumi.Input[str] route_mode: The routing pattern. Value: managed: indicates automatic mode
        :param pulumi.Input[str] tr_attachment_master_cidr: Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        :param pulumi.Input[str] tr_attachment_slave_cidr: Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        :param pulumi.Input[str] transit_router_id: The ID of the transit router instance.
        :param pulumi.Input[str] firewall_description: Firewall description.
        :param pulumi.Input[str] tr_attachment_master_zone: The primary zone of the switch.
        :param pulumi.Input[str] tr_attachment_slave_zone: Switch standby area.
        """
        pulumi.set(__self__, "cen_id", cen_id)
        pulumi.set(__self__, "firewall_name", firewall_name)
        pulumi.set(__self__, "firewall_subnet_cidr", firewall_subnet_cidr)
        pulumi.set(__self__, "firewall_vpc_cidr", firewall_vpc_cidr)
        pulumi.set(__self__, "region_no", region_no)
        pulumi.set(__self__, "route_mode", route_mode)
        pulumi.set(__self__, "tr_attachment_master_cidr", tr_attachment_master_cidr)
        pulumi.set(__self__, "tr_attachment_slave_cidr", tr_attachment_slave_cidr)
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if firewall_description is not None:
            pulumi.set(__self__, "firewall_description", firewall_description)
        if tr_attachment_master_zone is not None:
            pulumi.set(__self__, "tr_attachment_master_zone", tr_attachment_master_zone)
        if tr_attachment_slave_zone is not None:
            pulumi.set(__self__, "tr_attachment_slave_zone", tr_attachment_slave_zone)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Input[str]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="firewallName")
    def firewall_name(self) -> pulumi.Input[str]:
        """
        The name of Cloud Firewall.
        """
        return pulumi.get(self, "firewall_name")

    @firewall_name.setter
    def firewall_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "firewall_name", value)

    @property
    @pulumi.getter(name="firewallSubnetCidr")
    def firewall_subnet_cidr(self) -> pulumi.Input[str]:
        """
        Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        """
        return pulumi.get(self, "firewall_subnet_cidr")

    @firewall_subnet_cidr.setter
    def firewall_subnet_cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "firewall_subnet_cidr", value)

    @property
    @pulumi.getter(name="firewallVpcCidr")
    def firewall_vpc_cidr(self) -> pulumi.Input[str]:
        """
        Required in automatic mode,  th CIDR of firewall VPC.
        """
        return pulumi.get(self, "firewall_vpc_cidr")

    @firewall_vpc_cidr.setter
    def firewall_vpc_cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "firewall_vpc_cidr", value)

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> pulumi.Input[str]:
        """
        The region ID of the transit router instance.
        """
        return pulumi.get(self, "region_no")

    @region_no.setter
    def region_no(self, value: pulumi.Input[str]):
        pulumi.set(self, "region_no", value)

    @property
    @pulumi.getter(name="routeMode")
    def route_mode(self) -> pulumi.Input[str]:
        """
        The routing pattern. Value: managed: indicates automatic mode
        """
        return pulumi.get(self, "route_mode")

    @route_mode.setter
    def route_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "route_mode", value)

    @property
    @pulumi.getter(name="trAttachmentMasterCidr")
    def tr_attachment_master_cidr(self) -> pulumi.Input[str]:
        """
        Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        """
        return pulumi.get(self, "tr_attachment_master_cidr")

    @tr_attachment_master_cidr.setter
    def tr_attachment_master_cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "tr_attachment_master_cidr", value)

    @property
    @pulumi.getter(name="trAttachmentSlaveCidr")
    def tr_attachment_slave_cidr(self) -> pulumi.Input[str]:
        """
        Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        """
        return pulumi.get(self, "tr_attachment_slave_cidr")

    @tr_attachment_slave_cidr.setter
    def tr_attachment_slave_cidr(self, value: pulumi.Input[str]):
        pulumi.set(self, "tr_attachment_slave_cidr", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[str]:
        """
        The ID of the transit router instance.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="firewallDescription")
    def firewall_description(self) -> Optional[pulumi.Input[str]]:
        """
        Firewall description.
        """
        return pulumi.get(self, "firewall_description")

    @firewall_description.setter
    def firewall_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_description", value)

    @property
    @pulumi.getter(name="trAttachmentMasterZone")
    def tr_attachment_master_zone(self) -> Optional[pulumi.Input[str]]:
        """
        The primary zone of the switch.
        """
        return pulumi.get(self, "tr_attachment_master_zone")

    @tr_attachment_master_zone.setter
    def tr_attachment_master_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tr_attachment_master_zone", value)

    @property
    @pulumi.getter(name="trAttachmentSlaveZone")
    def tr_attachment_slave_zone(self) -> Optional[pulumi.Input[str]]:
        """
        Switch standby area.
        """
        return pulumi.get(self, "tr_attachment_slave_zone")

    @tr_attachment_slave_zone.setter
    def tr_attachment_slave_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tr_attachment_slave_zone", value)


@pulumi.input_type
class _VpcCenTrFirewallState:
    def __init__(__self__, *,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 firewall_description: Optional[pulumi.Input[str]] = None,
                 firewall_name: Optional[pulumi.Input[str]] = None,
                 firewall_subnet_cidr: Optional[pulumi.Input[str]] = None,
                 firewall_vpc_cidr: Optional[pulumi.Input[str]] = None,
                 region_no: Optional[pulumi.Input[str]] = None,
                 route_mode: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_cidr: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_zone: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_cidr: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_zone: Optional[pulumi.Input[str]] = None,
                 transit_router_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VpcCenTrFirewall resources.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] firewall_description: Firewall description.
        :param pulumi.Input[str] firewall_name: The name of Cloud Firewall.
        :param pulumi.Input[str] firewall_subnet_cidr: Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        :param pulumi.Input[str] firewall_vpc_cidr: Required in automatic mode,  th CIDR of firewall VPC.
        :param pulumi.Input[str] region_no: The region ID of the transit router instance.
        :param pulumi.Input[str] route_mode: The routing pattern. Value: managed: indicates automatic mode
        :param pulumi.Input[str] status: Firewall status. Value:
        :param pulumi.Input[str] tr_attachment_master_cidr: Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        :param pulumi.Input[str] tr_attachment_master_zone: The primary zone of the switch.
        :param pulumi.Input[str] tr_attachment_slave_cidr: Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        :param pulumi.Input[str] tr_attachment_slave_zone: Switch standby area.
        :param pulumi.Input[str] transit_router_id: The ID of the transit router instance.
        """
        if cen_id is not None:
            pulumi.set(__self__, "cen_id", cen_id)
        if firewall_description is not None:
            pulumi.set(__self__, "firewall_description", firewall_description)
        if firewall_name is not None:
            pulumi.set(__self__, "firewall_name", firewall_name)
        if firewall_subnet_cidr is not None:
            pulumi.set(__self__, "firewall_subnet_cidr", firewall_subnet_cidr)
        if firewall_vpc_cidr is not None:
            pulumi.set(__self__, "firewall_vpc_cidr", firewall_vpc_cidr)
        if region_no is not None:
            pulumi.set(__self__, "region_no", region_no)
        if route_mode is not None:
            pulumi.set(__self__, "route_mode", route_mode)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tr_attachment_master_cidr is not None:
            pulumi.set(__self__, "tr_attachment_master_cidr", tr_attachment_master_cidr)
        if tr_attachment_master_zone is not None:
            pulumi.set(__self__, "tr_attachment_master_zone", tr_attachment_master_zone)
        if tr_attachment_slave_cidr is not None:
            pulumi.set(__self__, "tr_attachment_slave_cidr", tr_attachment_slave_cidr)
        if tr_attachment_slave_zone is not None:
            pulumi.set(__self__, "tr_attachment_slave_zone", tr_attachment_slave_zone)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @cen_id.setter
    def cen_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cen_id", value)

    @property
    @pulumi.getter(name="firewallDescription")
    def firewall_description(self) -> Optional[pulumi.Input[str]]:
        """
        Firewall description.
        """
        return pulumi.get(self, "firewall_description")

    @firewall_description.setter
    def firewall_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_description", value)

    @property
    @pulumi.getter(name="firewallName")
    def firewall_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of Cloud Firewall.
        """
        return pulumi.get(self, "firewall_name")

    @firewall_name.setter
    def firewall_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_name", value)

    @property
    @pulumi.getter(name="firewallSubnetCidr")
    def firewall_subnet_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        """
        return pulumi.get(self, "firewall_subnet_cidr")

    @firewall_subnet_cidr.setter
    def firewall_subnet_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_subnet_cidr", value)

    @property
    @pulumi.getter(name="firewallVpcCidr")
    def firewall_vpc_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Required in automatic mode,  th CIDR of firewall VPC.
        """
        return pulumi.get(self, "firewall_vpc_cidr")

    @firewall_vpc_cidr.setter
    def firewall_vpc_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firewall_vpc_cidr", value)

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> Optional[pulumi.Input[str]]:
        """
        The region ID of the transit router instance.
        """
        return pulumi.get(self, "region_no")

    @region_no.setter
    def region_no(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_no", value)

    @property
    @pulumi.getter(name="routeMode")
    def route_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The routing pattern. Value: managed: indicates automatic mode
        """
        return pulumi.get(self, "route_mode")

    @route_mode.setter
    def route_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "route_mode", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Firewall status. Value:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="trAttachmentMasterCidr")
    def tr_attachment_master_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        """
        return pulumi.get(self, "tr_attachment_master_cidr")

    @tr_attachment_master_cidr.setter
    def tr_attachment_master_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tr_attachment_master_cidr", value)

    @property
    @pulumi.getter(name="trAttachmentMasterZone")
    def tr_attachment_master_zone(self) -> Optional[pulumi.Input[str]]:
        """
        The primary zone of the switch.
        """
        return pulumi.get(self, "tr_attachment_master_zone")

    @tr_attachment_master_zone.setter
    def tr_attachment_master_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tr_attachment_master_zone", value)

    @property
    @pulumi.getter(name="trAttachmentSlaveCidr")
    def tr_attachment_slave_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        """
        return pulumi.get(self, "tr_attachment_slave_cidr")

    @tr_attachment_slave_cidr.setter
    def tr_attachment_slave_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tr_attachment_slave_cidr", value)

    @property
    @pulumi.getter(name="trAttachmentSlaveZone")
    def tr_attachment_slave_zone(self) -> Optional[pulumi.Input[str]]:
        """
        Switch standby area.
        """
        return pulumi.get(self, "tr_attachment_slave_zone")

    @tr_attachment_slave_zone.setter
    def tr_attachment_slave_zone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tr_attachment_slave_zone", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the transit router instance.
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "transit_router_id", value)


class VpcCenTrFirewall(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 firewall_description: Optional[pulumi.Input[str]] = None,
                 firewall_name: Optional[pulumi.Input[str]] = None,
                 firewall_subnet_cidr: Optional[pulumi.Input[str]] = None,
                 firewall_vpc_cidr: Optional[pulumi.Input[str]] = None,
                 region_no: Optional[pulumi.Input[str]] = None,
                 route_mode: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_cidr: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_zone: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_cidr: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_zone: Optional[pulumi.Input[str]] = None,
                 transit_router_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Firewall Vpc Cen Tr Firewall resource.

        VPC firewall Cloud Enterprise Network Enterprise Edition.

        For information about Cloud Firewall Vpc Cen Tr Firewall and how to use it, see [What is Vpc Cen Tr Firewall](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_time as time

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        description = config.get("description")
        if description is None:
            description = "Created by Terraform"
        firewall_name = config.get("firewallName")
        if firewall_name is None:
            firewall_name = "tf-example"
        tr_attachment_master_cidr = config.get("trAttachmentMasterCidr")
        if tr_attachment_master_cidr is None:
            tr_attachment_master_cidr = "192.168.3.192/26"
        firewall_subnet_cidr = config.get("firewallSubnetCidr")
        if firewall_subnet_cidr is None:
            firewall_subnet_cidr = "192.168.3.0/25"
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        tr_attachment_slave_cidr = config.get("trAttachmentSlaveCidr")
        if tr_attachment_slave_cidr is None:
            tr_attachment_slave_cidr = "192.168.3.128/26"
        firewall_vpc_cidr = config.get("firewallVpcCidr")
        if firewall_vpc_cidr is None:
            firewall_vpc_cidr = "192.168.3.0/24"
        zone1 = config.get("zone1")
        if zone1 is None:
            zone1 = "cn-hangzhou-h"
        firewall_name_update = config.get("firewallNameUpdate")
        if firewall_name_update is None:
            firewall_name_update = "tf-example-1"
        zone2 = config.get("zone2")
        if zone2 is None:
            zone2 = "cn-hangzhou-i"
        default = alicloud.cen.get_transit_router_available_resources()
        default_get_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        cen = alicloud.cen.Instance("cen",
            description="terraform example",
            cen_instance_name=name)
        tr = alicloud.cen.TransitRouter("tr",
            transit_router_name=name,
            transit_router_description="tr-created-by-terraform",
            cen_id=cen.id)
        vpc1 = alicloud.vpc.Network("vpc1",
            description="created by terraform",
            cidr_block="192.168.1.0/24",
            vpc_name=name)
        vpc1vsw1 = alicloud.vpc.Switch("vpc1vsw1",
            cidr_block="192.168.1.0/25",
            vswitch_name=name,
            vpc_id=vpc1.id,
            zone_id=default.resources[0].master_zones[1])
        vpc1vsw2 = alicloud.vpc.Switch("vpc1vsw2",
            vpc_id=vpc1.id,
            cidr_block="192.168.1.128/26",
            vswitch_name=name,
            zone_id=default.resources[0].master_zones[2])
        foo = alicloud.vpc.RouteTable("foo",
            vpc_id=vpc1.id,
            route_table_name=name,
            description=name)
        tr_vpc1 = alicloud.cen.TransitRouterVpcAttachment("tr-vpc1",
            zone_mappings=[
                {
                    "vswitch_id": vpc1vsw1.id,
                    "zone_id": default.resources[0].master_zones[1],
                },
                {
                    "zone_id": default.resources[0].master_zones[2],
                    "vswitch_id": vpc1vsw2.id,
                },
            ],
            vpc_id=vpc1.id,
            cen_id=cen.id,
            transit_router_id=tr.transit_router_id,
            opts = pulumi.ResourceOptions(depends_on=[foo]))
        wait10_minutes = time.index.Sleep("wait_10_minutes", create_duration=10m,
        opts = pulumi.ResourceOptions(depends_on=[tr_vpc1]))
        default_vpc_cen_tr_firewall = alicloud.cloudfirewall.VpcCenTrFirewall("default",
            cen_id=tr_vpc1.cen_id,
            firewall_name=name,
            firewall_subnet_cidr=firewall_subnet_cidr,
            tr_attachment_slave_cidr=tr_attachment_slave_cidr,
            firewall_description="VpcCenTrFirewall created by terraform",
            region_no=region,
            tr_attachment_master_cidr=tr_attachment_master_cidr,
            firewall_vpc_cidr=firewall_vpc_cidr,
            transit_router_id=tr.transit_router_id,
            route_mode="managed",
            opts = pulumi.ResourceOptions(depends_on=[wait10_minutes]))
        ```

        ## Import

        Cloud Firewall Vpc Cen Tr Firewall can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/vpcCenTrFirewall:VpcCenTrFirewall example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] firewall_description: Firewall description.
        :param pulumi.Input[str] firewall_name: The name of Cloud Firewall.
        :param pulumi.Input[str] firewall_subnet_cidr: Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        :param pulumi.Input[str] firewall_vpc_cidr: Required in automatic mode,  th CIDR of firewall VPC.
        :param pulumi.Input[str] region_no: The region ID of the transit router instance.
        :param pulumi.Input[str] route_mode: The routing pattern. Value: managed: indicates automatic mode
        :param pulumi.Input[str] tr_attachment_master_cidr: Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        :param pulumi.Input[str] tr_attachment_master_zone: The primary zone of the switch.
        :param pulumi.Input[str] tr_attachment_slave_cidr: Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        :param pulumi.Input[str] tr_attachment_slave_zone: Switch standby area.
        :param pulumi.Input[str] transit_router_id: The ID of the transit router instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpcCenTrFirewallArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Firewall Vpc Cen Tr Firewall resource.

        VPC firewall Cloud Enterprise Network Enterprise Edition.

        For information about Cloud Firewall Vpc Cen Tr Firewall and how to use it, see [What is Vpc Cen Tr Firewall](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_time as time

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        description = config.get("description")
        if description is None:
            description = "Created by Terraform"
        firewall_name = config.get("firewallName")
        if firewall_name is None:
            firewall_name = "tf-example"
        tr_attachment_master_cidr = config.get("trAttachmentMasterCidr")
        if tr_attachment_master_cidr is None:
            tr_attachment_master_cidr = "192.168.3.192/26"
        firewall_subnet_cidr = config.get("firewallSubnetCidr")
        if firewall_subnet_cidr is None:
            firewall_subnet_cidr = "192.168.3.0/25"
        region = config.get("region")
        if region is None:
            region = "cn-hangzhou"
        tr_attachment_slave_cidr = config.get("trAttachmentSlaveCidr")
        if tr_attachment_slave_cidr is None:
            tr_attachment_slave_cidr = "192.168.3.128/26"
        firewall_vpc_cidr = config.get("firewallVpcCidr")
        if firewall_vpc_cidr is None:
            firewall_vpc_cidr = "192.168.3.0/24"
        zone1 = config.get("zone1")
        if zone1 is None:
            zone1 = "cn-hangzhou-h"
        firewall_name_update = config.get("firewallNameUpdate")
        if firewall_name_update is None:
            firewall_name_update = "tf-example-1"
        zone2 = config.get("zone2")
        if zone2 is None:
            zone2 = "cn-hangzhou-i"
        default = alicloud.cen.get_transit_router_available_resources()
        default_get_zones = alicloud.get_zones(available_resource_creation="VSwitch")
        cen = alicloud.cen.Instance("cen",
            description="terraform example",
            cen_instance_name=name)
        tr = alicloud.cen.TransitRouter("tr",
            transit_router_name=name,
            transit_router_description="tr-created-by-terraform",
            cen_id=cen.id)
        vpc1 = alicloud.vpc.Network("vpc1",
            description="created by terraform",
            cidr_block="192.168.1.0/24",
            vpc_name=name)
        vpc1vsw1 = alicloud.vpc.Switch("vpc1vsw1",
            cidr_block="192.168.1.0/25",
            vswitch_name=name,
            vpc_id=vpc1.id,
            zone_id=default.resources[0].master_zones[1])
        vpc1vsw2 = alicloud.vpc.Switch("vpc1vsw2",
            vpc_id=vpc1.id,
            cidr_block="192.168.1.128/26",
            vswitch_name=name,
            zone_id=default.resources[0].master_zones[2])
        foo = alicloud.vpc.RouteTable("foo",
            vpc_id=vpc1.id,
            route_table_name=name,
            description=name)
        tr_vpc1 = alicloud.cen.TransitRouterVpcAttachment("tr-vpc1",
            zone_mappings=[
                {
                    "vswitch_id": vpc1vsw1.id,
                    "zone_id": default.resources[0].master_zones[1],
                },
                {
                    "zone_id": default.resources[0].master_zones[2],
                    "vswitch_id": vpc1vsw2.id,
                },
            ],
            vpc_id=vpc1.id,
            cen_id=cen.id,
            transit_router_id=tr.transit_router_id,
            opts = pulumi.ResourceOptions(depends_on=[foo]))
        wait10_minutes = time.index.Sleep("wait_10_minutes", create_duration=10m,
        opts = pulumi.ResourceOptions(depends_on=[tr_vpc1]))
        default_vpc_cen_tr_firewall = alicloud.cloudfirewall.VpcCenTrFirewall("default",
            cen_id=tr_vpc1.cen_id,
            firewall_name=name,
            firewall_subnet_cidr=firewall_subnet_cidr,
            tr_attachment_slave_cidr=tr_attachment_slave_cidr,
            firewall_description="VpcCenTrFirewall created by terraform",
            region_no=region,
            tr_attachment_master_cidr=tr_attachment_master_cidr,
            firewall_vpc_cidr=firewall_vpc_cidr,
            transit_router_id=tr.transit_router_id,
            route_mode="managed",
            opts = pulumi.ResourceOptions(depends_on=[wait10_minutes]))
        ```

        ## Import

        Cloud Firewall Vpc Cen Tr Firewall can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/vpcCenTrFirewall:VpcCenTrFirewall example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VpcCenTrFirewallArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcCenTrFirewallArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cen_id: Optional[pulumi.Input[str]] = None,
                 firewall_description: Optional[pulumi.Input[str]] = None,
                 firewall_name: Optional[pulumi.Input[str]] = None,
                 firewall_subnet_cidr: Optional[pulumi.Input[str]] = None,
                 firewall_vpc_cidr: Optional[pulumi.Input[str]] = None,
                 region_no: Optional[pulumi.Input[str]] = None,
                 route_mode: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_cidr: Optional[pulumi.Input[str]] = None,
                 tr_attachment_master_zone: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_cidr: Optional[pulumi.Input[str]] = None,
                 tr_attachment_slave_zone: Optional[pulumi.Input[str]] = None,
                 transit_router_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcCenTrFirewallArgs.__new__(VpcCenTrFirewallArgs)

            if cen_id is None and not opts.urn:
                raise TypeError("Missing required property 'cen_id'")
            __props__.__dict__["cen_id"] = cen_id
            __props__.__dict__["firewall_description"] = firewall_description
            if firewall_name is None and not opts.urn:
                raise TypeError("Missing required property 'firewall_name'")
            __props__.__dict__["firewall_name"] = firewall_name
            if firewall_subnet_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'firewall_subnet_cidr'")
            __props__.__dict__["firewall_subnet_cidr"] = firewall_subnet_cidr
            if firewall_vpc_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'firewall_vpc_cidr'")
            __props__.__dict__["firewall_vpc_cidr"] = firewall_vpc_cidr
            if region_no is None and not opts.urn:
                raise TypeError("Missing required property 'region_no'")
            __props__.__dict__["region_no"] = region_no
            if route_mode is None and not opts.urn:
                raise TypeError("Missing required property 'route_mode'")
            __props__.__dict__["route_mode"] = route_mode
            if tr_attachment_master_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'tr_attachment_master_cidr'")
            __props__.__dict__["tr_attachment_master_cidr"] = tr_attachment_master_cidr
            __props__.__dict__["tr_attachment_master_zone"] = tr_attachment_master_zone
            if tr_attachment_slave_cidr is None and not opts.urn:
                raise TypeError("Missing required property 'tr_attachment_slave_cidr'")
            __props__.__dict__["tr_attachment_slave_cidr"] = tr_attachment_slave_cidr
            __props__.__dict__["tr_attachment_slave_zone"] = tr_attachment_slave_zone
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["status"] = None
        super(VpcCenTrFirewall, __self__).__init__(
            'alicloud:cloudfirewall/vpcCenTrFirewall:VpcCenTrFirewall',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cen_id: Optional[pulumi.Input[str]] = None,
            firewall_description: Optional[pulumi.Input[str]] = None,
            firewall_name: Optional[pulumi.Input[str]] = None,
            firewall_subnet_cidr: Optional[pulumi.Input[str]] = None,
            firewall_vpc_cidr: Optional[pulumi.Input[str]] = None,
            region_no: Optional[pulumi.Input[str]] = None,
            route_mode: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            tr_attachment_master_cidr: Optional[pulumi.Input[str]] = None,
            tr_attachment_master_zone: Optional[pulumi.Input[str]] = None,
            tr_attachment_slave_cidr: Optional[pulumi.Input[str]] = None,
            tr_attachment_slave_zone: Optional[pulumi.Input[str]] = None,
            transit_router_id: Optional[pulumi.Input[str]] = None) -> 'VpcCenTrFirewall':
        """
        Get an existing VpcCenTrFirewall resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] cen_id: The ID of the CEN instance.
        :param pulumi.Input[str] firewall_description: Firewall description.
        :param pulumi.Input[str] firewall_name: The name of Cloud Firewall.
        :param pulumi.Input[str] firewall_subnet_cidr: Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        :param pulumi.Input[str] firewall_vpc_cidr: Required in automatic mode,  th CIDR of firewall VPC.
        :param pulumi.Input[str] region_no: The region ID of the transit router instance.
        :param pulumi.Input[str] route_mode: The routing pattern. Value: managed: indicates automatic mode
        :param pulumi.Input[str] status: Firewall status. Value:
        :param pulumi.Input[str] tr_attachment_master_cidr: Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        :param pulumi.Input[str] tr_attachment_master_zone: The primary zone of the switch.
        :param pulumi.Input[str] tr_attachment_slave_cidr: Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        :param pulumi.Input[str] tr_attachment_slave_zone: Switch standby area.
        :param pulumi.Input[str] transit_router_id: The ID of the transit router instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcCenTrFirewallState.__new__(_VpcCenTrFirewallState)

        __props__.__dict__["cen_id"] = cen_id
        __props__.__dict__["firewall_description"] = firewall_description
        __props__.__dict__["firewall_name"] = firewall_name
        __props__.__dict__["firewall_subnet_cidr"] = firewall_subnet_cidr
        __props__.__dict__["firewall_vpc_cidr"] = firewall_vpc_cidr
        __props__.__dict__["region_no"] = region_no
        __props__.__dict__["route_mode"] = route_mode
        __props__.__dict__["status"] = status
        __props__.__dict__["tr_attachment_master_cidr"] = tr_attachment_master_cidr
        __props__.__dict__["tr_attachment_master_zone"] = tr_attachment_master_zone
        __props__.__dict__["tr_attachment_slave_cidr"] = tr_attachment_slave_cidr
        __props__.__dict__["tr_attachment_slave_zone"] = tr_attachment_slave_zone
        __props__.__dict__["transit_router_id"] = transit_router_id
        return VpcCenTrFirewall(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> pulumi.Output[str]:
        """
        The ID of the CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="firewallDescription")
    def firewall_description(self) -> pulumi.Output[Optional[str]]:
        """
        Firewall description.
        """
        return pulumi.get(self, "firewall_description")

    @property
    @pulumi.getter(name="firewallName")
    def firewall_name(self) -> pulumi.Output[str]:
        """
        The name of Cloud Firewall.
        """
        return pulumi.get(self, "firewall_name")

    @property
    @pulumi.getter(name="firewallSubnetCidr")
    def firewall_subnet_cidr(self) -> pulumi.Output[str]:
        """
        Required in automatic mode, the CIDR of subnet used to store the firewall ENI in the firewall VPC.
        """
        return pulumi.get(self, "firewall_subnet_cidr")

    @property
    @pulumi.getter(name="firewallVpcCidr")
    def firewall_vpc_cidr(self) -> pulumi.Output[str]:
        """
        Required in automatic mode,  th CIDR of firewall VPC.
        """
        return pulumi.get(self, "firewall_vpc_cidr")

    @property
    @pulumi.getter(name="regionNo")
    def region_no(self) -> pulumi.Output[str]:
        """
        The region ID of the transit router instance.
        """
        return pulumi.get(self, "region_no")

    @property
    @pulumi.getter(name="routeMode")
    def route_mode(self) -> pulumi.Output[str]:
        """
        The routing pattern. Value: managed: indicates automatic mode
        """
        return pulumi.get(self, "route_mode")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Firewall status. Value:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trAttachmentMasterCidr")
    def tr_attachment_master_cidr(self) -> pulumi.Output[str]:
        """
        Required in automatic mode, the primary CIDR of network used to connect to the TR in the firewall VPC.
        """
        return pulumi.get(self, "tr_attachment_master_cidr")

    @property
    @pulumi.getter(name="trAttachmentMasterZone")
    def tr_attachment_master_zone(self) -> pulumi.Output[Optional[str]]:
        """
        The primary zone of the switch.
        """
        return pulumi.get(self, "tr_attachment_master_zone")

    @property
    @pulumi.getter(name="trAttachmentSlaveCidr")
    def tr_attachment_slave_cidr(self) -> pulumi.Output[str]:
        """
        Required in automatic mode, the the secondary CIDR of the subnet in the firewall VPC used to connect to TR.
        """
        return pulumi.get(self, "tr_attachment_slave_cidr")

    @property
    @pulumi.getter(name="trAttachmentSlaveZone")
    def tr_attachment_slave_zone(self) -> pulumi.Output[Optional[str]]:
        """
        Switch standby area.
        """
        return pulumi.get(self, "tr_attachment_slave_zone")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[str]:
        """
        The ID of the transit router instance.
        """
        return pulumi.get(self, "transit_router_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BaselineArgs', 'Baseline']

@pulumi.input_type
class BaselineArgs:
    def __init__(__self__, *,
                 baseline_items: Optional[pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]]] = None,
                 baseline_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Baseline resource.
        :param pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]] baseline_items: List of baseline items.
               
               You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        :param pulumi.Input[str] baseline_name: Baseline Name.
        :param pulumi.Input[str] description: Baseline Description.
        """
        if baseline_items is not None:
            pulumi.set(__self__, "baseline_items", baseline_items)
        if baseline_name is not None:
            pulumi.set(__self__, "baseline_name", baseline_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="baselineItems")
    def baseline_items(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]]]:
        """
        List of baseline items.

        You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        """
        return pulumi.get(self, "baseline_items")

    @baseline_items.setter
    def baseline_items(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]]]):
        pulumi.set(self, "baseline_items", value)

    @property
    @pulumi.getter(name="baselineName")
    def baseline_name(self) -> Optional[pulumi.Input[str]]:
        """
        Baseline Name.
        """
        return pulumi.get(self, "baseline_name")

    @baseline_name.setter
    def baseline_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "baseline_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Baseline Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _BaselineState:
    def __init__(__self__, *,
                 baseline_items: Optional[pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]]] = None,
                 baseline_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Baseline resources.
        :param pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]] baseline_items: List of baseline items.
               
               You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        :param pulumi.Input[str] baseline_name: Baseline Name.
        :param pulumi.Input[str] description: Baseline Description.
        """
        if baseline_items is not None:
            pulumi.set(__self__, "baseline_items", baseline_items)
        if baseline_name is not None:
            pulumi.set(__self__, "baseline_name", baseline_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="baselineItems")
    def baseline_items(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]]]:
        """
        List of baseline items.

        You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        """
        return pulumi.get(self, "baseline_items")

    @baseline_items.setter
    def baseline_items(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BaselineBaselineItemArgs']]]]):
        pulumi.set(self, "baseline_items", value)

    @property
    @pulumi.getter(name="baselineName")
    def baseline_name(self) -> Optional[pulumi.Input[str]]:
        """
        Baseline Name.
        """
        return pulumi.get(self, "baseline_name")

    @baseline_name.setter
    def baseline_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "baseline_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Baseline Description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


class Baseline(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 baseline_items: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BaselineBaselineItemArgs', 'BaselineBaselineItemArgsDict']]]]] = None,
                 baseline_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Governance Baseline resource.

        Account Factory Baseline.

        For information about Governance Baseline and how to use it, see [What is Baseline](https://next.api.aliyun.com/document/governance/2021-01-20/CreateAccountFactoryBaseline).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        item_password_policy = config.get("itemPasswordPolicy")
        if item_password_policy is None:
            item_password_policy = "ACS-BP_ACCOUNT_FACTORY_RAM_USER_PASSWORD_POLICY"
        baseline_name_update = config.get("baselineNameUpdate")
        if baseline_name_update is None:
            baseline_name_update = "tf-auto-example-baseline-update"
        item_services = config.get("itemServices")
        if item_services is None:
            item_services = "ACS-BP_ACCOUNT_FACTORY_SUBSCRIBE_SERVICES"
        baseline_name = config.get("baselineName")
        if baseline_name is None:
            baseline_name = "tf-auto-example-baseline"
        item_ram_security = config.get("itemRamSecurity")
        if item_ram_security is None:
            item_ram_security = "ACS-BP_ACCOUNT_FACTORY_RAM_SECURITY_PREFERENCE"
        default_baseline = alicloud.governance.Baseline("default",
            baseline_items=[{
                "version": "1.0",
                "name": item_password_policy,
                "config": json.dumps({
                    "MinimumPasswordLength": 8,
                    "RequireLowercaseCharacters": True,
                    "RequireUppercaseCharacters": True,
                    "RequireNumbers": True,
                    "RequireSymbols": True,
                    "MaxPasswordAge": 0,
                    "HardExpiry": False,
                    "PasswordReusePrevention": 0,
                    "MaxLoginAttempts": 0,
                }),
            }],
            description=name,
            baseline_name=f"{name}-{default['result']}")
        ```

        ## Import

        Governance Baseline can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:governance/baseline:Baseline example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BaselineBaselineItemArgs', 'BaselineBaselineItemArgsDict']]]] baseline_items: List of baseline items.
               
               You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        :param pulumi.Input[str] baseline_name: Baseline Name.
        :param pulumi.Input[str] description: Baseline Description.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[BaselineArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Governance Baseline resource.

        Account Factory Baseline.

        For information about Governance Baseline and how to use it, see [What is Baseline](https://next.api.aliyun.com/document/governance/2021-01-20/CreateAccountFactoryBaseline).

        > **NOTE:** Available since v1.228.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        item_password_policy = config.get("itemPasswordPolicy")
        if item_password_policy is None:
            item_password_policy = "ACS-BP_ACCOUNT_FACTORY_RAM_USER_PASSWORD_POLICY"
        baseline_name_update = config.get("baselineNameUpdate")
        if baseline_name_update is None:
            baseline_name_update = "tf-auto-example-baseline-update"
        item_services = config.get("itemServices")
        if item_services is None:
            item_services = "ACS-BP_ACCOUNT_FACTORY_SUBSCRIBE_SERVICES"
        baseline_name = config.get("baselineName")
        if baseline_name is None:
            baseline_name = "tf-auto-example-baseline"
        item_ram_security = config.get("itemRamSecurity")
        if item_ram_security is None:
            item_ram_security = "ACS-BP_ACCOUNT_FACTORY_RAM_SECURITY_PREFERENCE"
        default_baseline = alicloud.governance.Baseline("default",
            baseline_items=[{
                "version": "1.0",
                "name": item_password_policy,
                "config": json.dumps({
                    "MinimumPasswordLength": 8,
                    "RequireLowercaseCharacters": True,
                    "RequireUppercaseCharacters": True,
                    "RequireNumbers": True,
                    "RequireSymbols": True,
                    "MaxPasswordAge": 0,
                    "HardExpiry": False,
                    "PasswordReusePrevention": 0,
                    "MaxLoginAttempts": 0,
                }),
            }],
            description=name,
            baseline_name=f"{name}-{default['result']}")
        ```

        ## Import

        Governance Baseline can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:governance/baseline:Baseline example <id>
        ```

        :param str resource_name: The name of the resource.
        :param BaselineArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BaselineArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 baseline_items: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BaselineBaselineItemArgs', 'BaselineBaselineItemArgsDict']]]]] = None,
                 baseline_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BaselineArgs.__new__(BaselineArgs)

            __props__.__dict__["baseline_items"] = baseline_items
            __props__.__dict__["baseline_name"] = baseline_name
            __props__.__dict__["description"] = description
        super(Baseline, __self__).__init__(
            'alicloud:governance/baseline:Baseline',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            baseline_items: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BaselineBaselineItemArgs', 'BaselineBaselineItemArgsDict']]]]] = None,
            baseline_name: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None) -> 'Baseline':
        """
        Get an existing Baseline resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BaselineBaselineItemArgs', 'BaselineBaselineItemArgsDict']]]] baseline_items: List of baseline items.
               
               You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        :param pulumi.Input[str] baseline_name: Baseline Name.
        :param pulumi.Input[str] description: Baseline Description.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BaselineState.__new__(_BaselineState)

        __props__.__dict__["baseline_items"] = baseline_items
        __props__.__dict__["baseline_name"] = baseline_name
        __props__.__dict__["description"] = description
        return Baseline(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="baselineItems")
    def baseline_items(self) -> pulumi.Output[Optional[Sequence['outputs.BaselineBaselineItem']]]:
        """
        List of baseline items.

        You can invoke [ListAccountFactoryBaselineItems](https://next.api.aliyun.com/document/governance/2021-01-20/ListAccountFactoryBaselineItems) to get a list of account factory baseline items supported by the Cloud Governance Center. See `baseline_items` below.
        """
        return pulumi.get(self, "baseline_items")

    @property
    @pulumi.getter(name="baselineName")
    def baseline_name(self) -> pulumi.Output[Optional[str]]:
        """
        Baseline Name.
        """
        return pulumi.get(self, "baseline_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Baseline Description.
        """
        return pulumi.get(self, "description")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BucketRefererArgs', 'BucketReferer']

@pulumi.input_type
class BucketRefererArgs:
    def __init__(__self__, *,
                 allow_empty_referer: pulumi.Input[bool],
                 bucket: pulumi.Input[str],
                 allow_truncate_query_string: Optional[pulumi.Input[bool]] = None,
                 referer_blacklists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 referer_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 truncate_path: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a BucketReferer resource.
        :param pulumi.Input[bool] allow_empty_referer: Whether to allow empty Referer request headers.
        :param pulumi.Input[str] bucket: Name of the Bucket.
        :param pulumi.Input[bool] allow_truncate_query_string: Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_blacklists: The container that holds the Referer blacklist.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_lists: The container that holds the Referer whitelist.
        :param pulumi.Input[bool] truncate_path: Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        pulumi.set(__self__, "allow_empty_referer", allow_empty_referer)
        pulumi.set(__self__, "bucket", bucket)
        if allow_truncate_query_string is not None:
            pulumi.set(__self__, "allow_truncate_query_string", allow_truncate_query_string)
        if referer_blacklists is not None:
            pulumi.set(__self__, "referer_blacklists", referer_blacklists)
        if referer_lists is not None:
            pulumi.set(__self__, "referer_lists", referer_lists)
        if truncate_path is not None:
            pulumi.set(__self__, "truncate_path", truncate_path)

    @property
    @pulumi.getter(name="allowEmptyReferer")
    def allow_empty_referer(self) -> pulumi.Input[bool]:
        """
        Whether to allow empty Referer request headers.
        """
        return pulumi.get(self, "allow_empty_referer")

    @allow_empty_referer.setter
    def allow_empty_referer(self, value: pulumi.Input[bool]):
        pulumi.set(self, "allow_empty_referer", value)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        Name of the Bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="allowTruncateQueryString")
    def allow_truncate_query_string(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        """
        return pulumi.get(self, "allow_truncate_query_string")

    @allow_truncate_query_string.setter
    def allow_truncate_query_string(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_truncate_query_string", value)

    @property
    @pulumi.getter(name="refererBlacklists")
    def referer_blacklists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The container that holds the Referer blacklist.
        """
        return pulumi.get(self, "referer_blacklists")

    @referer_blacklists.setter
    def referer_blacklists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "referer_blacklists", value)

    @property
    @pulumi.getter(name="refererLists")
    def referer_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The container that holds the Referer whitelist.
        """
        return pulumi.get(self, "referer_lists")

    @referer_lists.setter
    def referer_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "referer_lists", value)

    @property
    @pulumi.getter(name="truncatePath")
    def truncate_path(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        return pulumi.get(self, "truncate_path")

    @truncate_path.setter
    def truncate_path(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "truncate_path", value)


@pulumi.input_type
class _BucketRefererState:
    def __init__(__self__, *,
                 allow_empty_referer: Optional[pulumi.Input[bool]] = None,
                 allow_truncate_query_string: Optional[pulumi.Input[bool]] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 referer_blacklists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 referer_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 truncate_path: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering BucketReferer resources.
        :param pulumi.Input[bool] allow_empty_referer: Whether to allow empty Referer request headers.
        :param pulumi.Input[bool] allow_truncate_query_string: Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        :param pulumi.Input[str] bucket: Name of the Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_blacklists: The container that holds the Referer blacklist.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_lists: The container that holds the Referer whitelist.
        :param pulumi.Input[bool] truncate_path: Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        if allow_empty_referer is not None:
            pulumi.set(__self__, "allow_empty_referer", allow_empty_referer)
        if allow_truncate_query_string is not None:
            pulumi.set(__self__, "allow_truncate_query_string", allow_truncate_query_string)
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if referer_blacklists is not None:
            pulumi.set(__self__, "referer_blacklists", referer_blacklists)
        if referer_lists is not None:
            pulumi.set(__self__, "referer_lists", referer_lists)
        if truncate_path is not None:
            pulumi.set(__self__, "truncate_path", truncate_path)

    @property
    @pulumi.getter(name="allowEmptyReferer")
    def allow_empty_referer(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to allow empty Referer request headers.
        """
        return pulumi.get(self, "allow_empty_referer")

    @allow_empty_referer.setter
    def allow_empty_referer(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_empty_referer", value)

    @property
    @pulumi.getter(name="allowTruncateQueryString")
    def allow_truncate_query_string(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        """
        return pulumi.get(self, "allow_truncate_query_string")

    @allow_truncate_query_string.setter
    def allow_truncate_query_string(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_truncate_query_string", value)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the Bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="refererBlacklists")
    def referer_blacklists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The container that holds the Referer blacklist.
        """
        return pulumi.get(self, "referer_blacklists")

    @referer_blacklists.setter
    def referer_blacklists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "referer_blacklists", value)

    @property
    @pulumi.getter(name="refererLists")
    def referer_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The container that holds the Referer whitelist.
        """
        return pulumi.get(self, "referer_lists")

    @referer_lists.setter
    def referer_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "referer_lists", value)

    @property
    @pulumi.getter(name="truncatePath")
    def truncate_path(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        return pulumi.get(self, "truncate_path")

    @truncate_path.setter
    def truncate_path(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "truncate_path", value)


class BucketReferer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_empty_referer: Optional[pulumi.Input[bool]] = None,
                 allow_truncate_query_string: Optional[pulumi.Input[bool]] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 referer_blacklists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 referer_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 truncate_path: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Provides a OSS Bucket Referer resource. Bucket Referer configuration (Hotlink protection).

        For information about OSS Bucket Referer and how to use it, see [What is Bucket Referer](https://www.alibabacloud.com/help/en/oss/user-guide/hotlink-protection).

        > **NOTE:** Available since v1.220.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        create_bucket = alicloud.oss.Bucket("CreateBucket",
            storage_class="Standard",
            bucket=f"{name}-{default['result']}")
        default_bucket_referer = alicloud.oss.BucketReferer("default",
            allow_empty_referer=True,
            referer_blacklists=["*.forbidden.com"],
            bucket=create_bucket.bucket,
            truncate_path=False,
            allow_truncate_query_string=True,
            referer_lists=[
                "*.aliyun.com",
                "*.example.com",
            ],
            opts = pulumi.ResourceOptions(depends_on=[create_bucket]))
        ```

        ## Import

        OSS Bucket Referer can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketReferer:BucketReferer example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_empty_referer: Whether to allow empty Referer request headers.
        :param pulumi.Input[bool] allow_truncate_query_string: Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        :param pulumi.Input[str] bucket: Name of the Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_blacklists: The container that holds the Referer blacklist.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_lists: The container that holds the Referer whitelist.
        :param pulumi.Input[bool] truncate_path: Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BucketRefererArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a OSS Bucket Referer resource. Bucket Referer configuration (Hotlink protection).

        For information about OSS Bucket Referer and how to use it, see [What is Bucket Referer](https://www.alibabacloud.com/help/en/oss/user-guide/hotlink-protection).

        > **NOTE:** Available since v1.220.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        create_bucket = alicloud.oss.Bucket("CreateBucket",
            storage_class="Standard",
            bucket=f"{name}-{default['result']}")
        default_bucket_referer = alicloud.oss.BucketReferer("default",
            allow_empty_referer=True,
            referer_blacklists=["*.forbidden.com"],
            bucket=create_bucket.bucket,
            truncate_path=False,
            allow_truncate_query_string=True,
            referer_lists=[
                "*.aliyun.com",
                "*.example.com",
            ],
            opts = pulumi.ResourceOptions(depends_on=[create_bucket]))
        ```

        ## Import

        OSS Bucket Referer can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketReferer:BucketReferer example <id>
        ```

        :param str resource_name: The name of the resource.
        :param BucketRefererArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BucketRefererArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_empty_referer: Optional[pulumi.Input[bool]] = None,
                 allow_truncate_query_string: Optional[pulumi.Input[bool]] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 referer_blacklists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 referer_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 truncate_path: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BucketRefererArgs.__new__(BucketRefererArgs)

            if allow_empty_referer is None and not opts.urn:
                raise TypeError("Missing required property 'allow_empty_referer'")
            __props__.__dict__["allow_empty_referer"] = allow_empty_referer
            __props__.__dict__["allow_truncate_query_string"] = allow_truncate_query_string
            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            __props__.__dict__["referer_blacklists"] = referer_blacklists
            __props__.__dict__["referer_lists"] = referer_lists
            __props__.__dict__["truncate_path"] = truncate_path
        super(BucketReferer, __self__).__init__(
            'alicloud:oss/bucketReferer:BucketReferer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_empty_referer: Optional[pulumi.Input[bool]] = None,
            allow_truncate_query_string: Optional[pulumi.Input[bool]] = None,
            bucket: Optional[pulumi.Input[str]] = None,
            referer_blacklists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            referer_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            truncate_path: Optional[pulumi.Input[bool]] = None) -> 'BucketReferer':
        """
        Get an existing BucketReferer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_empty_referer: Whether to allow empty Referer request headers.
        :param pulumi.Input[bool] allow_truncate_query_string: Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        :param pulumi.Input[str] bucket: Name of the Bucket.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_blacklists: The container that holds the Referer blacklist.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] referer_lists: The container that holds the Referer whitelist.
        :param pulumi.Input[bool] truncate_path: Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BucketRefererState.__new__(_BucketRefererState)

        __props__.__dict__["allow_empty_referer"] = allow_empty_referer
        __props__.__dict__["allow_truncate_query_string"] = allow_truncate_query_string
        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["referer_blacklists"] = referer_blacklists
        __props__.__dict__["referer_lists"] = referer_lists
        __props__.__dict__["truncate_path"] = truncate_path
        return BucketReferer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowEmptyReferer")
    def allow_empty_referer(self) -> pulumi.Output[bool]:
        """
        Whether to allow empty Referer request headers.
        """
        return pulumi.get(self, "allow_empty_referer")

    @property
    @pulumi.getter(name="allowTruncateQueryString")
    def allow_truncate_query_string(self) -> pulumi.Output[bool]:
        """
        Specifies whether to truncate the query string in the URL when the Referer is matched. Valid values: true, false.
        """
        return pulumi.get(self, "allow_truncate_query_string")

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[str]:
        """
        Name of the Bucket.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="refererBlacklists")
    def referer_blacklists(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The container that holds the Referer blacklist.
        """
        return pulumi.get(self, "referer_blacklists")

    @property
    @pulumi.getter(name="refererLists")
    def referer_lists(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The container that holds the Referer whitelist.
        """
        return pulumi.get(self, "referer_lists")

    @property
    @pulumi.getter(name="truncatePath")
    def truncate_path(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to truncate the path and parts that follow the path in the URL when the Referer is matched. Valid values: true, false. If TruncatePath is set to true, the value of AllowTruncateQueryString must be also true because the query string follows the path component. When the path is truncated, the query string is also truncated.
        """
        return pulumi.get(self, "truncate_path")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLoadBalancersResult',
    'AwaitableGetLoadBalancersResult',
    'get_load_balancers',
    'get_load_balancers_output',
]

@pulumi.output_type
class GetLoadBalancersResult:
    """
    A collection of values returned by getLoadBalancers.
    """
    def __init__(__self__, address_ip_version=None, address_type=None, balancers=None, dns_name=None, id=None, ids=None, ipv6_address_type=None, load_balancer_business_status=None, load_balancer_names=None, name_regex=None, names=None, output_file=None, resource_group_id=None, status=None, tags=None, vpc_ids=None, zone_id=None):
        if address_ip_version and not isinstance(address_ip_version, str):
            raise TypeError("Expected argument 'address_ip_version' to be a str")
        pulumi.set(__self__, "address_ip_version", address_ip_version)
        if address_type and not isinstance(address_type, str):
            raise TypeError("Expected argument 'address_type' to be a str")
        pulumi.set(__self__, "address_type", address_type)
        if balancers and not isinstance(balancers, list):
            raise TypeError("Expected argument 'balancers' to be a list")
        pulumi.set(__self__, "balancers", balancers)
        if dns_name and not isinstance(dns_name, str):
            raise TypeError("Expected argument 'dns_name' to be a str")
        pulumi.set(__self__, "dns_name", dns_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if ipv6_address_type and not isinstance(ipv6_address_type, str):
            raise TypeError("Expected argument 'ipv6_address_type' to be a str")
        pulumi.set(__self__, "ipv6_address_type", ipv6_address_type)
        if load_balancer_business_status and not isinstance(load_balancer_business_status, str):
            raise TypeError("Expected argument 'load_balancer_business_status' to be a str")
        pulumi.set(__self__, "load_balancer_business_status", load_balancer_business_status)
        if load_balancer_names and not isinstance(load_balancer_names, list):
            raise TypeError("Expected argument 'load_balancer_names' to be a list")
        pulumi.set(__self__, "load_balancer_names", load_balancer_names)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if vpc_ids and not isinstance(vpc_ids, list):
            raise TypeError("Expected argument 'vpc_ids' to be a list")
        pulumi.set(__self__, "vpc_ids", vpc_ids)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> Optional[str]:
        return pulumi.get(self, "address_ip_version")

    @property
    @pulumi.getter(name="addressType")
    def address_type(self) -> Optional[str]:
        return pulumi.get(self, "address_type")

    @property
    @pulumi.getter
    def balancers(self) -> Sequence['outputs.GetLoadBalancersBalancerResult']:
        return pulumi.get(self, "balancers")

    @property
    @pulumi.getter(name="dnsName")
    def dns_name(self) -> Optional[str]:
        return pulumi.get(self, "dns_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="ipv6AddressType")
    def ipv6_address_type(self) -> Optional[str]:
        return pulumi.get(self, "ipv6_address_type")

    @property
    @pulumi.getter(name="loadBalancerBusinessStatus")
    def load_balancer_business_status(self) -> Optional[str]:
        return pulumi.get(self, "load_balancer_business_status")

    @property
    @pulumi.getter(name="loadBalancerNames")
    def load_balancer_names(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "load_balancer_names")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vpcIds")
    def vpc_ids(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "vpc_ids")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[str]:
        return pulumi.get(self, "zone_id")


class AwaitableGetLoadBalancersResult(GetLoadBalancersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLoadBalancersResult(
            address_ip_version=self.address_ip_version,
            address_type=self.address_type,
            balancers=self.balancers,
            dns_name=self.dns_name,
            id=self.id,
            ids=self.ids,
            ipv6_address_type=self.ipv6_address_type,
            load_balancer_business_status=self.load_balancer_business_status,
            load_balancer_names=self.load_balancer_names,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            status=self.status,
            tags=self.tags,
            vpc_ids=self.vpc_ids,
            zone_id=self.zone_id)


def get_load_balancers(address_ip_version: Optional[str] = None,
                       address_type: Optional[str] = None,
                       dns_name: Optional[str] = None,
                       ids: Optional[Sequence[str]] = None,
                       ipv6_address_type: Optional[str] = None,
                       load_balancer_business_status: Optional[str] = None,
                       load_balancer_names: Optional[Sequence[str]] = None,
                       name_regex: Optional[str] = None,
                       output_file: Optional[str] = None,
                       resource_group_id: Optional[str] = None,
                       status: Optional[str] = None,
                       tags: Optional[Mapping[str, str]] = None,
                       vpc_ids: Optional[Sequence[str]] = None,
                       zone_id: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLoadBalancersResult:
    """
    This data source provides the Nlb Load Balancers of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.191.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nlb.get_load_balancers(ids=["example_id"])
    pulumi.export("nlbLoadBalancerId1", ids.balancers[0].id)
    name_regex = alicloud.nlb.get_load_balancers(name_regex="^my-LoadBalancer")
    pulumi.export("nlbLoadBalancerId2", name_regex.balancers[0].id)
    ```


    :param str address_ip_version: The IP version. Valid values: `ipv4`, `DualStack`.
    :param str address_type: The type of IPv4 address used by the NLB instance. Valid values: `Internet`, `Intranet`.
    :param str dns_name: The domain name of the NLB instance.
    :param Sequence[str] ids: A list of Load Balancer IDs.
    :param str ipv6_address_type: The type of IPv6 address used by the NLB instance. Valid values: `Internet`, `Intranet`.
    :param str load_balancer_business_status: The business status of the NLB instance. Valid values: `Abnormal`, `Normal`.
    :param Sequence[str] load_balancer_names: The name of the NLB instance. You can specify at most 10 names.
    :param str name_regex: A regex string to filter results by Load Balancer name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group.
    :param str status: The status of the NLB instance. Valid values: `Inactive`, `Active`, `Provisioning`, `Configuring`, `Deleting`, `Deleted`.
    :param Sequence[str] vpc_ids: The ID of the virtual private cloud (VPC) where the NLB instance is deployed. You can specify at most 10 IDs.
    :param str zone_id: The name of the zone.
    """
    __args__ = dict()
    __args__['addressIpVersion'] = address_ip_version
    __args__['addressType'] = address_type
    __args__['dnsName'] = dns_name
    __args__['ids'] = ids
    __args__['ipv6AddressType'] = ipv6_address_type
    __args__['loadBalancerBusinessStatus'] = load_balancer_business_status
    __args__['loadBalancerNames'] = load_balancer_names
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcIds'] = vpc_ids
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:nlb/getLoadBalancers:getLoadBalancers', __args__, opts=opts, typ=GetLoadBalancersResult).value

    return AwaitableGetLoadBalancersResult(
        address_ip_version=pulumi.get(__ret__, 'address_ip_version'),
        address_type=pulumi.get(__ret__, 'address_type'),
        balancers=pulumi.get(__ret__, 'balancers'),
        dns_name=pulumi.get(__ret__, 'dns_name'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        ipv6_address_type=pulumi.get(__ret__, 'ipv6_address_type'),
        load_balancer_business_status=pulumi.get(__ret__, 'load_balancer_business_status'),
        load_balancer_names=pulumi.get(__ret__, 'load_balancer_names'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        vpc_ids=pulumi.get(__ret__, 'vpc_ids'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_load_balancers_output(address_ip_version: Optional[pulumi.Input[Optional[str]]] = None,
                              address_type: Optional[pulumi.Input[Optional[str]]] = None,
                              dns_name: Optional[pulumi.Input[Optional[str]]] = None,
                              ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              ipv6_address_type: Optional[pulumi.Input[Optional[str]]] = None,
                              load_balancer_business_status: Optional[pulumi.Input[Optional[str]]] = None,
                              load_balancer_names: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                              output_file: Optional[pulumi.Input[Optional[str]]] = None,
                              resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                              status: Optional[pulumi.Input[Optional[str]]] = None,
                              tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                              vpc_ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              zone_id: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetLoadBalancersResult]:
    """
    This data source provides the Nlb Load Balancers of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.191.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.nlb.get_load_balancers(ids=["example_id"])
    pulumi.export("nlbLoadBalancerId1", ids.balancers[0].id)
    name_regex = alicloud.nlb.get_load_balancers(name_regex="^my-LoadBalancer")
    pulumi.export("nlbLoadBalancerId2", name_regex.balancers[0].id)
    ```


    :param str address_ip_version: The IP version. Valid values: `ipv4`, `DualStack`.
    :param str address_type: The type of IPv4 address used by the NLB instance. Valid values: `Internet`, `Intranet`.
    :param str dns_name: The domain name of the NLB instance.
    :param Sequence[str] ids: A list of Load Balancer IDs.
    :param str ipv6_address_type: The type of IPv6 address used by the NLB instance. Valid values: `Internet`, `Intranet`.
    :param str load_balancer_business_status: The business status of the NLB instance. Valid values: `Abnormal`, `Normal`.
    :param Sequence[str] load_balancer_names: The name of the NLB instance. You can specify at most 10 names.
    :param str name_regex: A regex string to filter results by Load Balancer name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group.
    :param str status: The status of the NLB instance. Valid values: `Inactive`, `Active`, `Provisioning`, `Configuring`, `Deleting`, `Deleted`.
    :param Sequence[str] vpc_ids: The ID of the virtual private cloud (VPC) where the NLB instance is deployed. You can specify at most 10 IDs.
    :param str zone_id: The name of the zone.
    """
    __args__ = dict()
    __args__['addressIpVersion'] = address_ip_version
    __args__['addressType'] = address_type
    __args__['dnsName'] = dns_name
    __args__['ids'] = ids
    __args__['ipv6AddressType'] = ipv6_address_type
    __args__['loadBalancerBusinessStatus'] = load_balancer_business_status
    __args__['loadBalancerNames'] = load_balancer_names
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vpcIds'] = vpc_ids
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:nlb/getLoadBalancers:getLoadBalancers', __args__, opts=opts, typ=GetLoadBalancersResult)
    return __ret__.apply(lambda __response__: GetLoadBalancersResult(
        address_ip_version=pulumi.get(__response__, 'address_ip_version'),
        address_type=pulumi.get(__response__, 'address_type'),
        balancers=pulumi.get(__response__, 'balancers'),
        dns_name=pulumi.get(__response__, 'dns_name'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        ipv6_address_type=pulumi.get(__response__, 'ipv6_address_type'),
        load_balancer_business_status=pulumi.get(__response__, 'load_balancer_business_status'),
        load_balancer_names=pulumi.get(__response__, 'load_balancer_names'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        vpc_ids=pulumi.get(__response__, 'vpc_ids'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApplicationInfoArgs', 'ApplicationInfo']

@pulumi.input_type
class ApplicationInfoArgs:
    def __init__(__self__, *,
                 desire_value: pulumi.Input[float],
                 product_code: pulumi.Input[str],
                 quota_action_code: pulumi.Input[str],
                 reason: pulumi.Input[str],
                 audit_mode: Optional[pulumi.Input[str]] = None,
                 dimensions: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationInfoDimensionArgs']]]] = None,
                 effective_time: Optional[pulumi.Input[str]] = None,
                 env_language: Optional[pulumi.Input[str]] = None,
                 expire_time: Optional[pulumi.Input[str]] = None,
                 notice_type: Optional[pulumi.Input[int]] = None,
                 quota_category: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ApplicationInfo resource.
        """
        pulumi.set(__self__, "desire_value", desire_value)
        pulumi.set(__self__, "product_code", product_code)
        pulumi.set(__self__, "quota_action_code", quota_action_code)
        pulumi.set(__self__, "reason", reason)
        if audit_mode is not None:
            pulumi.set(__self__, "audit_mode", audit_mode)
        if dimensions is not None:
            pulumi.set(__self__, "dimensions", dimensions)
        if effective_time is not None:
            pulumi.set(__self__, "effective_time", effective_time)
        if env_language is not None:
            pulumi.set(__self__, "env_language", env_language)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if notice_type is not None:
            pulumi.set(__self__, "notice_type", notice_type)
        if quota_category is not None:
            pulumi.set(__self__, "quota_category", quota_category)

    @property
    @pulumi.getter(name="desireValue")
    def desire_value(self) -> pulumi.Input[float]:
        return pulumi.get(self, "desire_value")

    @desire_value.setter
    def desire_value(self, value: pulumi.Input[float]):
        pulumi.set(self, "desire_value", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Input[str]:
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter(name="quotaActionCode")
    def quota_action_code(self) -> pulumi.Input[str]:
        return pulumi.get(self, "quota_action_code")

    @quota_action_code.setter
    def quota_action_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "quota_action_code", value)

    @property
    @pulumi.getter
    def reason(self) -> pulumi.Input[str]:
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: pulumi.Input[str]):
        pulumi.set(self, "reason", value)

    @property
    @pulumi.getter(name="auditMode")
    def audit_mode(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "audit_mode")

    @audit_mode.setter
    def audit_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audit_mode", value)

    @property
    @pulumi.getter
    def dimensions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationInfoDimensionArgs']]]]:
        return pulumi.get(self, "dimensions")

    @dimensions.setter
    def dimensions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationInfoDimensionArgs']]]]):
        pulumi.set(self, "dimensions", value)

    @property
    @pulumi.getter(name="effectiveTime")
    def effective_time(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "effective_time")

    @effective_time.setter
    def effective_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effective_time", value)

    @property
    @pulumi.getter(name="envLanguage")
    def env_language(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "env_language")

    @env_language.setter
    def env_language(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "env_language", value)

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expire_time", value)

    @property
    @pulumi.getter(name="noticeType")
    def notice_type(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "notice_type")

    @notice_type.setter
    def notice_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notice_type", value)

    @property
    @pulumi.getter(name="quotaCategory")
    def quota_category(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quota_category")

    @quota_category.setter
    def quota_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quota_category", value)


@pulumi.input_type
class _ApplicationInfoState:
    def __init__(__self__, *,
                 approve_value: Optional[pulumi.Input[str]] = None,
                 audit_mode: Optional[pulumi.Input[str]] = None,
                 audit_reason: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 desire_value: Optional[pulumi.Input[float]] = None,
                 dimensions: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationInfoDimensionArgs']]]] = None,
                 effective_time: Optional[pulumi.Input[str]] = None,
                 env_language: Optional[pulumi.Input[str]] = None,
                 expire_time: Optional[pulumi.Input[str]] = None,
                 notice_type: Optional[pulumi.Input[int]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 quota_action_code: Optional[pulumi.Input[str]] = None,
                 quota_category: Optional[pulumi.Input[str]] = None,
                 quota_description: Optional[pulumi.Input[str]] = None,
                 quota_name: Optional[pulumi.Input[str]] = None,
                 quota_unit: Optional[pulumi.Input[str]] = None,
                 reason: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ApplicationInfo resources.
        """
        if approve_value is not None:
            pulumi.set(__self__, "approve_value", approve_value)
        if audit_mode is not None:
            pulumi.set(__self__, "audit_mode", audit_mode)
        if audit_reason is not None:
            pulumi.set(__self__, "audit_reason", audit_reason)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if desire_value is not None:
            pulumi.set(__self__, "desire_value", desire_value)
        if dimensions is not None:
            pulumi.set(__self__, "dimensions", dimensions)
        if effective_time is not None:
            pulumi.set(__self__, "effective_time", effective_time)
        if env_language is not None:
            pulumi.set(__self__, "env_language", env_language)
        if expire_time is not None:
            pulumi.set(__self__, "expire_time", expire_time)
        if notice_type is not None:
            pulumi.set(__self__, "notice_type", notice_type)
        if product_code is not None:
            pulumi.set(__self__, "product_code", product_code)
        if quota_action_code is not None:
            pulumi.set(__self__, "quota_action_code", quota_action_code)
        if quota_category is not None:
            pulumi.set(__self__, "quota_category", quota_category)
        if quota_description is not None:
            pulumi.set(__self__, "quota_description", quota_description)
        if quota_name is not None:
            pulumi.set(__self__, "quota_name", quota_name)
        if quota_unit is not None:
            pulumi.set(__self__, "quota_unit", quota_unit)
        if reason is not None:
            pulumi.set(__self__, "reason", reason)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="approveValue")
    def approve_value(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "approve_value")

    @approve_value.setter
    def approve_value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "approve_value", value)

    @property
    @pulumi.getter(name="auditMode")
    def audit_mode(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "audit_mode")

    @audit_mode.setter
    def audit_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audit_mode", value)

    @property
    @pulumi.getter(name="auditReason")
    def audit_reason(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "audit_reason")

    @audit_reason.setter
    def audit_reason(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "audit_reason", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="desireValue")
    def desire_value(self) -> Optional[pulumi.Input[float]]:
        return pulumi.get(self, "desire_value")

    @desire_value.setter
    def desire_value(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "desire_value", value)

    @property
    @pulumi.getter
    def dimensions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationInfoDimensionArgs']]]]:
        return pulumi.get(self, "dimensions")

    @dimensions.setter
    def dimensions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationInfoDimensionArgs']]]]):
        pulumi.set(self, "dimensions", value)

    @property
    @pulumi.getter(name="effectiveTime")
    def effective_time(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "effective_time")

    @effective_time.setter
    def effective_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "effective_time", value)

    @property
    @pulumi.getter(name="envLanguage")
    def env_language(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "env_language")

    @env_language.setter
    def env_language(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "env_language", value)

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "expire_time")

    @expire_time.setter
    def expire_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expire_time", value)

    @property
    @pulumi.getter(name="noticeType")
    def notice_type(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "notice_type")

    @notice_type.setter
    def notice_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "notice_type", value)

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "product_code")

    @product_code.setter
    def product_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_code", value)

    @property
    @pulumi.getter(name="quotaActionCode")
    def quota_action_code(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quota_action_code")

    @quota_action_code.setter
    def quota_action_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quota_action_code", value)

    @property
    @pulumi.getter(name="quotaCategory")
    def quota_category(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quota_category")

    @quota_category.setter
    def quota_category(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quota_category", value)

    @property
    @pulumi.getter(name="quotaDescription")
    def quota_description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quota_description")

    @quota_description.setter
    def quota_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quota_description", value)

    @property
    @pulumi.getter(name="quotaName")
    def quota_name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quota_name")

    @quota_name.setter
    def quota_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quota_name", value)

    @property
    @pulumi.getter(name="quotaUnit")
    def quota_unit(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "quota_unit")

    @quota_unit.setter
    def quota_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "quota_unit", value)

    @property
    @pulumi.getter
    def reason(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "reason")

    @reason.setter
    def reason(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reason", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class ApplicationInfo(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audit_mode: Optional[pulumi.Input[str]] = None,
                 desire_value: Optional[pulumi.Input[float]] = None,
                 dimensions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationInfoDimensionArgs', 'ApplicationInfoDimensionArgsDict']]]]] = None,
                 effective_time: Optional[pulumi.Input[str]] = None,
                 env_language: Optional[pulumi.Input[str]] = None,
                 expire_time: Optional[pulumi.Input[str]] = None,
                 notice_type: Optional[pulumi.Input[int]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 quota_action_code: Optional[pulumi.Input[str]] = None,
                 quota_category: Optional[pulumi.Input[str]] = None,
                 reason: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a ApplicationInfo resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationInfoArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a ApplicationInfo resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param ApplicationInfoArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationInfoArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 audit_mode: Optional[pulumi.Input[str]] = None,
                 desire_value: Optional[pulumi.Input[float]] = None,
                 dimensions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationInfoDimensionArgs', 'ApplicationInfoDimensionArgsDict']]]]] = None,
                 effective_time: Optional[pulumi.Input[str]] = None,
                 env_language: Optional[pulumi.Input[str]] = None,
                 expire_time: Optional[pulumi.Input[str]] = None,
                 notice_type: Optional[pulumi.Input[int]] = None,
                 product_code: Optional[pulumi.Input[str]] = None,
                 quota_action_code: Optional[pulumi.Input[str]] = None,
                 quota_category: Optional[pulumi.Input[str]] = None,
                 reason: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationInfoArgs.__new__(ApplicationInfoArgs)

            __props__.__dict__["audit_mode"] = audit_mode
            if desire_value is None and not opts.urn:
                raise TypeError("Missing required property 'desire_value'")
            __props__.__dict__["desire_value"] = desire_value
            __props__.__dict__["dimensions"] = dimensions
            __props__.__dict__["effective_time"] = effective_time
            __props__.__dict__["env_language"] = env_language
            __props__.__dict__["expire_time"] = expire_time
            __props__.__dict__["notice_type"] = notice_type
            if product_code is None and not opts.urn:
                raise TypeError("Missing required property 'product_code'")
            __props__.__dict__["product_code"] = product_code
            if quota_action_code is None and not opts.urn:
                raise TypeError("Missing required property 'quota_action_code'")
            __props__.__dict__["quota_action_code"] = quota_action_code
            __props__.__dict__["quota_category"] = quota_category
            if reason is None and not opts.urn:
                raise TypeError("Missing required property 'reason'")
            __props__.__dict__["reason"] = reason
            __props__.__dict__["approve_value"] = None
            __props__.__dict__["audit_reason"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["quota_description"] = None
            __props__.__dict__["quota_name"] = None
            __props__.__dict__["quota_unit"] = None
            __props__.__dict__["status"] = None
        super(ApplicationInfo, __self__).__init__(
            'alicloud:quotas/applicationInfo:ApplicationInfo',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            approve_value: Optional[pulumi.Input[str]] = None,
            audit_mode: Optional[pulumi.Input[str]] = None,
            audit_reason: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            desire_value: Optional[pulumi.Input[float]] = None,
            dimensions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationInfoDimensionArgs', 'ApplicationInfoDimensionArgsDict']]]]] = None,
            effective_time: Optional[pulumi.Input[str]] = None,
            env_language: Optional[pulumi.Input[str]] = None,
            expire_time: Optional[pulumi.Input[str]] = None,
            notice_type: Optional[pulumi.Input[int]] = None,
            product_code: Optional[pulumi.Input[str]] = None,
            quota_action_code: Optional[pulumi.Input[str]] = None,
            quota_category: Optional[pulumi.Input[str]] = None,
            quota_description: Optional[pulumi.Input[str]] = None,
            quota_name: Optional[pulumi.Input[str]] = None,
            quota_unit: Optional[pulumi.Input[str]] = None,
            reason: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'ApplicationInfo':
        """
        Get an existing ApplicationInfo resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationInfoState.__new__(_ApplicationInfoState)

        __props__.__dict__["approve_value"] = approve_value
        __props__.__dict__["audit_mode"] = audit_mode
        __props__.__dict__["audit_reason"] = audit_reason
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["desire_value"] = desire_value
        __props__.__dict__["dimensions"] = dimensions
        __props__.__dict__["effective_time"] = effective_time
        __props__.__dict__["env_language"] = env_language
        __props__.__dict__["expire_time"] = expire_time
        __props__.__dict__["notice_type"] = notice_type
        __props__.__dict__["product_code"] = product_code
        __props__.__dict__["quota_action_code"] = quota_action_code
        __props__.__dict__["quota_category"] = quota_category
        __props__.__dict__["quota_description"] = quota_description
        __props__.__dict__["quota_name"] = quota_name
        __props__.__dict__["quota_unit"] = quota_unit
        __props__.__dict__["reason"] = reason
        __props__.__dict__["status"] = status
        return ApplicationInfo(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="approveValue")
    def approve_value(self) -> pulumi.Output[str]:
        return pulumi.get(self, "approve_value")

    @property
    @pulumi.getter(name="auditMode")
    def audit_mode(self) -> pulumi.Output[str]:
        return pulumi.get(self, "audit_mode")

    @property
    @pulumi.getter(name="auditReason")
    def audit_reason(self) -> pulumi.Output[str]:
        return pulumi.get(self, "audit_reason")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="desireValue")
    def desire_value(self) -> pulumi.Output[float]:
        return pulumi.get(self, "desire_value")

    @property
    @pulumi.getter
    def dimensions(self) -> pulumi.Output[Optional[Sequence['outputs.ApplicationInfoDimension']]]:
        return pulumi.get(self, "dimensions")

    @property
    @pulumi.getter(name="effectiveTime")
    def effective_time(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "effective_time")

    @property
    @pulumi.getter(name="envLanguage")
    def env_language(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "env_language")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter(name="noticeType")
    def notice_type(self) -> pulumi.Output[int]:
        return pulumi.get(self, "notice_type")

    @property
    @pulumi.getter(name="productCode")
    def product_code(self) -> pulumi.Output[str]:
        return pulumi.get(self, "product_code")

    @property
    @pulumi.getter(name="quotaActionCode")
    def quota_action_code(self) -> pulumi.Output[str]:
        return pulumi.get(self, "quota_action_code")

    @property
    @pulumi.getter(name="quotaCategory")
    def quota_category(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "quota_category")

    @property
    @pulumi.getter(name="quotaDescription")
    def quota_description(self) -> pulumi.Output[str]:
        return pulumi.get(self, "quota_description")

    @property
    @pulumi.getter(name="quotaName")
    def quota_name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "quota_name")

    @property
    @pulumi.getter(name="quotaUnit")
    def quota_unit(self) -> pulumi.Output[str]:
        return pulumi.get(self, "quota_unit")

    @property
    @pulumi.getter
    def reason(self) -> pulumi.Output[str]:
        return pulumi.get(self, "reason")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        return pulumi.get(self, "status")

